import flask
from subprocess import run

app = flask.Flask(__name__, static_url_path="")

DATABASE = ":memory:"


@app.route("/")
def index():
    return flask.render_template("index.html")


@app.route("/query", methods=["POST"])
def runquery():
    query = flask.request.get_data(as_text=True)
    result = run(["sqlite3", "-header", "-html", DATABASE, query], capture_output=True)
    return flask.jsonify(
        dict(result=result.stdout.decode(), error=result.stderr.decode())
    )


def main():
    global DATABASE
    import argparse

    parser = argparse.ArgumentParser()
    parser.add_argument(
        "sqlite_db",
        nargs="?",
        help="SQLite database to interact with. Defaults to in-memory db.",
    )
    args = parser.parse_args()

    if args.sqlite_db:
        DATABASE = args.sqlite_db

    app.run(debug=True)


if __name__ == "__main__":
    main()



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sqimple']

package_data = \
{'': ['*'], 'sqimple': ['static/*', 'templates/*']}

entry_points = \
{'console_scripts': ['sqimple = sqimple.server:main']}

setup(name='sqimple',
      version='0.0.2',
      description='Simple SQLite Web Interface',
      author='Zach Gulde',
      author_email='zachgulde@gmail.com',
      url=None,
      packages=packages,
      package_data=package_data,
      entry_points=entry_points,
     )
